@@ -18,9 +18,7 @@ class ViewingAngleSampler(NonObservedAuxSampler):
 
         """
 
-        super(ViewingAngleSampler, self).__init__(
-            name="va",
-        )
+        super(ViewingAngleSampler, self).__init__(name="va", )
 
     def true_sampler(self, size: int) -> None:
         """
@@ -32,8 +30,9 @@ class ViewingAngleSampler(NonObservedAuxSampler):
 
         """
 
-        theta_inverse = np.random.uniform(
-            0.0, 1 - np.cos(np.deg2rad(self.max_angle)), size=size
-        )
+        theta_inverse = np.random.uniform(0.0,
+                                          1 -
+                                          np.cos(np.deg2rad(self.max_angle)),
+                                          size=size)
 
         self._true_values = np.arccos(1.0 - theta_inverse)
