@@ -5,4 +5,4 @@ from popsynth.utils.configuration import popsynth_config
 
 def progress_bar(itr, **kwargs):
 
-    return (tqdm(itr, **kwargs) if popsynth_config["show_progress"] else itr)
+    return (tqdm(itr, **kwargs) if popsynth_config.show_progress else itr)
